@@ -1,6 +1,7 @@
 # nolint start
 bibentries <- c(
-  grimme2018ifo = bibentry("article",
+  grimme2018ifo = bibentry(
+    "article",
     title = "Das ifo Importklima -- ein erster Fr\u00FChindikator f\u00FCr die Prognose der deutschen Importe",
     author = "Christian Grimme and Robert Lehmann and Marvin N\u00F6ller",
     journal = "ifo Schnelldienst",
@@ -10,7 +11,8 @@ bibentries <- c(
     year = "2018",
     publisher = "ifo Institut -- Leibniz-Institut f\u00FCr Wirtschaftsforschung an der Universit\u00E4t M\u00FCnchen",
   ),
-  grimme2021forecasting = bibentry("article",
+  grimme2021forecasting = bibentry(
+    "article",
     title = "Forecasting imports with information from abroad",
     author = "Grimme, Christian and Lehmann, Robert and N\u00F6ller, Marvin",
     journal = "Economic Modelling",
